==> react-native-ui-xep-0.1.28.tgz: package/src/atoms/select/Select.tsx <==
import React, { FC } from 'react';
import { styles } from './styles';
import {
  Icon,
  Item,
  Label,
  NativeBase,
  Picker,
  RnViewStyleProp,
  Text,
} from 'native-base';
import * as ReactNative from 'react-native';
import { View, Platform } from 'react-native';

export type SelectProps = NativeBase.Picker & {
  type?: 'material' | 'custom' | 'bordered' | 'material-black';
  pickerProps?: ReactNative.PickerItemProps;
  pickerList: [{ value: string; label: string; color?: string }];
  selectStyle?: any;
  labelProps?: NativeBase.Label;
  selectProps?: NativeBase.Input;
  label?: string;
  style?: RnViewStyleProp;
  validationInfo?: string[];
};
export const Select: FC<SelectProps> = (props: SelectProps) => {
  const {
    selectStyle,
    validationInfo,
    label,
    style,
    labelProps,
    type,
    pickerList,
    pickerProps,
  } = props;
  const propsX = props;
  delete propsX.style;
  const renderElement = (selectStyleX?: any, labelStyle?: any) => {
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
            {'   '}
            {validationInfo && validationInfo?.length > 0 && (
              <Text style={{ color: '#f39c12', marginLeft: 5 }}>
                {validationInfo}
              </Text>
            )}
          </Label>
        )}
        <View style={selectStyleX}>
          <Picker
            iosIcon={
              <Icon
                style={{ alignSelf: 'center', color: '#C4C4C4' }}
                name="arrow-down"
              />
            }
            placeholderStyle={{
              color: '#C4C4C4',
              fontSize: 16,
              lineHeight: 18,
            }}
            itemTextStyle={{ color: '#4a4a4a' }}
            itemStyle={{ fontSize: 14 }}
            textStyle={{ color: '#4a4a4a' }}
            mode="dropdown"
            {...propsX}
            style={[selectStyle]}
          >
            {pickerList
              .filter((val) => !(Platform.OS === 'ios' && val.value === ''))
              .map((item, index) => {
                return (
                  <Picker.Item
                    key={index}
                    label={item.label}
                    value={item.value}
                    color={item.color ?? '#4a4a4a'}
                    {...pickerProps}
                  />
                );
              })}
          </Picker>
        </View>
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(styles.material, styles.textMaterial);
    case 'bordered':
      return renderElement(styles.bordered, {
        ...styles.textDefault,
        color: '#979797',
      });
    case 'material-black':
      return renderElement(
        [styles.material, { color: 'black', borderColor: 'black' }],
        {
          ...styles.textDefault,
          color: 'black',
        }
      );
    default:
      return renderElement(styles.default, styles.textDefault);
  }
};

==> react-native-ui-xep-0.1.31.tgz: package/src/atoms/select/Select.tsx <==
import React, { FC } from 'react';
import { styles } from './styles';
import {
  Icon,
  Item,
  Label,
  NativeBase,
  Picker,
  RnViewStyleProp,
} from 'native-base';
import * as ReactNative from 'react-native';
import { View, Platform } from 'react-native';
import {
  borderedInputVariables,
  primaryInputVariables,
} from '../../Configurations/ThemeConfig';

export type SelectProps = NativeBase.Picker & {
  type?: 'material' | 'custom' | 'bordered' | 'material-black';
  pickerProps?: ReactNative.PickerItemProps;
  pickerList: [{ value: string; label: string; color?: string }];
  selectStyle?: any;
  labelProps?: NativeBase.Label;
  selectProps?: NativeBase.Input;
  label?: string;
  style?: RnViewStyleProp;
  validationInfo?: string[];
};
export const Select: FC<SelectProps> = (props: SelectProps) => {
  const {
    selectStyle,
    label,
    style,
    labelProps,
    type,
    pickerList,
    pickerProps,
  } = props;
  const propsX = props;
  delete propsX.style;
  const renderElement = (
    selectStyleX?: any,
    labelStyle?: any,
    placeholderTextColor?: string
  ) => {
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
          </Label>
        )}
        <View style={selectStyleX}>
          <Picker
            iosIcon={
              <Icon
                style={{
                  alignSelf: 'center',
                  color: placeholderTextColor ?? '#C4C4C4',
                }}
                name="arrow-down"
              />
            }
            placeholderStyle={{
              color: placeholderTextColor ?? '#C4C4C4',
              fontSize: 16,
              lineHeight: 18,
            }}
            itemTextStyle={{ color: '#4a4a4a' }}
            itemStyle={{ fontSize: 14 }}
            textStyle={{ color: '#4a4a4a' }}
            mode="dropdown"
            {...propsX}
            style={[selectStyle]}
          >
            {pickerList
              .filter((val) => !(Platform.OS === 'ios' && val.value === ''))
              .map((item, index) => {
                return (
                  <Picker.Item
                    key={index}
                    label={item.label}
                    value={item.value}
                    color={item.color ?? '#4a4a4a'}
                    {...pickerProps}
                  />
                );
              })}
          </Picker>
        </View>
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(styles.material, styles.textMaterial);
    case 'bordered':
      return renderElement(
        styles.bordered,
        {
          ...styles.textDefault,
          color: borderedInputVariables.labelColor,
          marginLeft: 10,
          fontWeight: 'bold',
        },
        borderedInputVariables.placeholderColor
      );
    case 'material-black':
      return renderElement(
        [styles.material, { color: 'black', borderColor: 'black' }],
        {
          ...styles.textDefault,
          color: 'black',
        }
      );
    default:
      return renderElement(
        styles.default,
        styles.textDefault,
        primaryInputVariables.placeholderColor
      );
  }
};
